package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcSafetyCounty;
import com.ruoyi.zongzhi.service.ITcSafetyCountyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 安全隐患统计Controller
 * 
 * @author ruoyi
 * @date 2023-09-20
 */
@RestController
@RequestMapping("/zongzhi/county")
@Api(tags = " 安全隐患统计")
public class TcSafetyCountyController extends BaseController
{
    @Autowired
    private ITcSafetyCountyService tcSafetyCountyService;

    /**
     * 查询安全隐患统计列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:county:list')")
    @GetMapping("/list")
    public TableDataInfo list(TcSafetyCounty tcSafetyCounty)
    {
        startPage();
        List<TcSafetyCounty> list = tcSafetyCountyService.selectTcSafetyCountyList(tcSafetyCounty);
        return getDataTable(list);
    }

    /**
     * 导出安全隐患统计列表
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:county:export')")
    @Log(title = "安全隐患统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSafetyCounty tcSafetyCounty)
    {
        List<TcSafetyCounty> list = tcSafetyCountyService.selectTcSafetyCountyList(tcSafetyCounty);
        ExcelUtil<TcSafetyCounty> util = new ExcelUtil<TcSafetyCounty>(TcSafetyCounty.class);
        util.exportExcel(response, list, "安全隐患统计数据");
    }

    /**
     * 获取安全隐患统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:county:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcSafetyCountyService.selectTcSafetyCountyById(id));
    }

    /**
     * 新增安全隐患统计
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:county:add')")
    @Log(title = "安全隐患统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcSafetyCounty tcSafetyCounty)
    {
        return toAjax(tcSafetyCountyService.insertTcSafetyCounty(tcSafetyCounty));
    }

    /**
     * 修改安全隐患统计
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:county:edit')")
    @Log(title = "安全隐患统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcSafetyCounty tcSafetyCounty)
    {
        return toAjax(tcSafetyCountyService.updateTcSafetyCounty(tcSafetyCounty));
    }

    /**
     * 删除安全隐患统计
     */
    @PreAuthorize("@ss.hasPermi('zongzhi:county:remove')")
    @Log(title = "安全隐患统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcSafetyCountyService.deleteTcSafetyCountyByIds(ids));
    }
}
